@@ -6,4 +6,4 @@ __version__ = '0.1'
 
 from .lamp import *
 from .helper import *
-from .utlies import *
\ No newline at end of file
+from .utils import *
\ No newline at end of file
